==> kubernetes-model-storageclass-5.1.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/storage/VolumeAttachmentStatusFluent.java <==
package io.fabric8.kubernetes.api.model.storage;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface VolumeAttachmentStatusFluent<A extends VolumeAttachmentStatusFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildAttachError instead.
 * @return The buildable object.
 */
@Deprecated public VolumeError getAttachError();
    public VolumeError buildAttachError();
    public A withAttachError(VolumeError attachError);
    public Boolean hasAttachError();
    public A withNewAttachError(String message,String time);
    public VolumeAttachmentStatusFluent.AttachErrorNested<A> withNewAttachError();
    public VolumeAttachmentStatusFluent.AttachErrorNested<A> withNewAttachErrorLike(VolumeError item);
    public VolumeAttachmentStatusFluent.AttachErrorNested<A> editAttachError();
    public VolumeAttachmentStatusFluent.AttachErrorNested<A> editOrNewAttachError();
    public VolumeAttachmentStatusFluent.AttachErrorNested<A> editOrNewAttachErrorLike(VolumeError item);
    public Boolean isAttached();
    public A withAttached(Boolean attached);
    public Boolean hasAttached();
    public A withNewAttached(String arg1);
    public A withNewAttached(boolean arg1);
    public A addToAttachmentMetadata(String key,String value);
    public A addToAttachmentMetadata(Map<String,String> map);
    public A removeFromAttachmentMetadata(String key);
    public A removeFromAttachmentMetadata(Map<String,String> map);
    public Map<String,String> getAttachmentMetadata();
    public A withAttachmentMetadata(Map<String,String> attachmentMetadata);
    public Boolean hasAttachmentMetadata();
    
/**
 * This method has been deprecated, please use method buildDetachError instead.
 * @return The buildable object.
 */
@Deprecated public VolumeError getDetachError();
    public VolumeError buildDetachError();
    public A withDetachError(VolumeError detachError);
    public Boolean hasDetachError();
    public A withNewDetachError(String message,String time);
    public VolumeAttachmentStatusFluent.DetachErrorNested<A> withNewDetachError();
    public VolumeAttachmentStatusFluent.DetachErrorNested<A> withNewDetachErrorLike(VolumeError item);
    public VolumeAttachmentStatusFluent.DetachErrorNested<A> editDetachError();
    public VolumeAttachmentStatusFluent.DetachErrorNested<A> editOrNewDetachError();
    public VolumeAttachmentStatusFluent.DetachErrorNested<A> editOrNewDetachErrorLike(VolumeError item);
    public interface AttachErrorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,VolumeErrorFluent<VolumeAttachmentStatusFluent.AttachErrorNested<N>> {

            public N and();
            public N endAttachError();    }


    public interface DetachErrorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,VolumeErrorFluent<VolumeAttachmentStatusFluent.DetachErrorNested<N>> {

            public N and();
            public N endDetachError();    }


}

==> kubernetes-model-storageclass-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/storage/VolumeAttachmentStatusFluent.java <==
package io.fabric8.kubernetes.api.model.storage;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface VolumeAttachmentStatusFluent<A extends VolumeAttachmentStatusFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildAttachError instead.
 * @return The buildable object.
 */
@Deprecated public VolumeError getAttachError();
    public VolumeError buildAttachError();
    public A withAttachError(VolumeError attachError);
    public Boolean hasAttachError();
    public A withNewAttachError(String message,String time);
    public VolumeAttachmentStatusFluent.AttachErrorNested<A> withNewAttachError();
    public VolumeAttachmentStatusFluent.AttachErrorNested<A> withNewAttachErrorLike(VolumeError item);
    public VolumeAttachmentStatusFluent.AttachErrorNested<A> editAttachError();
    public VolumeAttachmentStatusFluent.AttachErrorNested<A> editOrNewAttachError();
    public VolumeAttachmentStatusFluent.AttachErrorNested<A> editOrNewAttachErrorLike(VolumeError item);
    public Boolean getAttached();
    public A withAttached(Boolean attached);
    public Boolean hasAttached();
    public A withNewAttached(String arg1);
    public A withNewAttached(boolean arg1);
    public A addToAttachmentMetadata(String key,String value);
    public A addToAttachmentMetadata(Map<String,String> map);
    public A removeFromAttachmentMetadata(String key);
    public A removeFromAttachmentMetadata(Map<String,String> map);
    public Map<String,String> getAttachmentMetadata();
    public <K extends Object,V extends Object>A withAttachmentMetadata(Map<String,String> attachmentMetadata);
    public Boolean hasAttachmentMetadata();
    
/**
 * This method has been deprecated, please use method buildDetachError instead.
 * @return The buildable object.
 */
@Deprecated public VolumeError getDetachError();
    public VolumeError buildDetachError();
    public A withDetachError(VolumeError detachError);
    public Boolean hasDetachError();
    public A withNewDetachError(String message,String time);
    public VolumeAttachmentStatusFluent.DetachErrorNested<A> withNewDetachError();
    public VolumeAttachmentStatusFluent.DetachErrorNested<A> withNewDetachErrorLike(VolumeError item);
    public VolumeAttachmentStatusFluent.DetachErrorNested<A> editDetachError();
    public VolumeAttachmentStatusFluent.DetachErrorNested<A> editOrNewDetachError();
    public VolumeAttachmentStatusFluent.DetachErrorNested<A> editOrNewDetachErrorLike(VolumeError item);
    public interface AttachErrorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,VolumeErrorFluent<VolumeAttachmentStatusFluent.AttachErrorNested<N>> {

            public N and();
            public N endAttachError();    }


    public interface DetachErrorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,VolumeErrorFluent<VolumeAttachmentStatusFluent.DetachErrorNested<N>> {

            public N and();
            public N endDetachError();    }


}
